WebViewGlobalConfig class

全局WebView配置管理

Constructors

WebViewGlobalConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

globalCustomEvents Map<String, String>?
获取全局自定义事件配置
no setter
globalEventCallbacks Map<String, dynamic Function(BuildContext context, String event)>?
获取全局事件回调函数
no setter
globalEventHandlers List<BaseEventHandler>?
获取全局事件处理器列表
no setter

Static Methods

addGlobalEvent(String jsMethodName, String channelName) → void
添加单个全局事件配置
addGlobalEventCallback(String jsMethodName, dynamic callback(BuildContext context, String event)) → void
添加单个全局事件回调
addGlobalEventHandler(BaseEventHandler handler) → void
添加全局事件处理器
clearGlobalConfig() → void
清除全局配置
removeGlobalEvent(String jsMethodName) → void
移除单个全局事件配置
removeGlobalEventCallback(String jsMethodName) → void
移除单个全局事件回调
removeGlobalEventHandler(BaseEventHandler handler) → void
移除全局事件处理器
setGlobalConfig({Map<String, String>? customEvents, Map<String, dynamic Function(BuildContext context, String event)>? eventCallbacks, List<BaseEventHandler>? eventHandlers}) → void
设置全局配置
setGlobalCustomEvents(Map<String, String> events) → void
设置全局自定义事件配置
setGlobalEventCallbacks(Map<String, dynamic Function(BuildContext context, String event)> callbacks) → void
设置全局事件回调函数
setGlobalEventHandlers(List<BaseEventHandler> handlers) → void
设置全局事件处理器列表